@@ -9,7 +9,7 @@ class TestPSF(object):
         pass
 
     def test_displace_psf(self):
-        psf = PSF(psf_type='GAUSSIAN', fwhm=1, moffat_beta=2.6)
+        psf = PSF(psf_type='GAUSSIAN', fwhm=1)
         np.random.seed(41)
         x, y = psf.displace_psf(0, 0)
         assert x != 0
@@ -27,4 +27,4 @@ class TestRaise(unittest.TestCase):
     def test_raise(self):
         with self.assertRaises(ValueError):
             psf = PSF(psf_type='BRRR', fwhm=1, moffat_beta=2.6)
-            psf.displace_psf(0, 0)
\ No newline at end of file
+            #psf.displace_psf(0, 0)
